.. _contributing:

Contributing to Weblate
=======================


There are dozens of ways to contribute in Weblate. Any help is welcomed, be it
coding, graphics design, documentation or sponsorship:

* :doc:`issues`
* :doc:`start`
* :ref:`translating-weblate`
* :ref:`funding-weblate`

.. _translating-weblate:

Translating Weblate
-------------------

Weblate is being `translated <https://hosted.weblate.org/>`_ using Weblate itself, feel
free to take part in the effort of making Weblate available in as many human languages
as possible.

.. _funding-weblate:

Funding Weblate development
---------------------------

You can fund further Weblate development on the `donate page`_. Funds collected
there are used to fund gratis hosting for libre software projects, and further
development of Weblate. Please check the `donate page` for details, such
as funding goals and rewards you can get for being a funder.

.. include:: ../../BACKERS.rst


.. _donate page: https://weblate.org/donate/
